==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/instanceaccess/impl/CreateNoVariableSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.instanceaccess.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.body.ACT_SMTSet;
import io.ciera.tool.sql.ooaofooa.body.impl.ACT_SMTSetImpl;
import io.ciera.tool.sql.ooaofooa.instanceaccess.CreateNoVariable;
import io.ciera.tool.sql.ooaofooa.instanceaccess.CreateNoVariableSet;
import io.ciera.tool.sql.ooaofooa.subsystem.ModelClassSet;
import io.ciera.tool.sql.ooaofooa.subsystem.impl.ModelClassSetImpl;

import java.util.Arrays;
import java.util.List;


public class CreateNoVariableSetImpl extends InstanceSet<CreateNoVariableSet,CreateNoVariable> implements CreateNoVariableSet {

    // attributes
    @Override
    public void setStatement_ID( UniqueId ref_Statement_ID ) throws XtumlException {
        for ( CreateNoVariable createnovariable : this ) createnovariable.setStatement_ID( ref_Statement_ID );
    }
    @Override
    public void setModelClassKeyLettersLineNumber( int m_modelClassKeyLettersLineNumber ) throws XtumlException {
        for ( CreateNoVariable createnovariable : this ) createnovariable.setModelClassKeyLettersLineNumber( m_modelClassKeyLettersLineNumber );
    }
    @Override
    public void setObj_ID( UniqueId ref_Obj_ID ) throws XtumlException {
        for ( CreateNoVariable createnovariable : this ) createnovariable.setObj_ID( ref_Obj_ID );
    }
    @Override
    public void setModelClassKeyLettersColumn( int m_modelClassKeyLettersColumn ) throws XtumlException {
        for ( CreateNoVariable createnovariable : this ) createnovariable.setModelClassKeyLettersColumn( m_modelClassKeyLettersColumn );
    }


    // selections
    @Override
    public ACT_SMTSet R603_is_a_ACT_SMT() throws XtumlException {
        ACT_SMTSet act_smtset = new ACT_SMTSetImpl();
        for ( CreateNoVariable createnovariable : this ) act_smtset.add( createnovariable.R603_is_a_ACT_SMT() );
        return act_smtset;
    }
    @Override
    public ModelClassSet R672_instance_of_ModelClass() throws XtumlException {
        ModelClassSet modelclassset = new ModelClassSetImpl();
        for ( CreateNoVariable createnovariable : this ) modelclassset.add( createnovariable.R672_instance_of_ModelClass() );
        return modelclassset;
    }


    @Override
    public CreateNoVariable nullElement() {
        return CreateNoVariableImpl.EMPTY_CREATENOVARIABLE;
    }

    @Override
    public CreateNoVariableSet emptySet() {
      return new CreateNoVariableSetImpl();
    }

    @Override
    public CreateNoVariableSet value() {
        return this;
    }

    @Override
    public List<CreateNoVariable> elements() {
        return Arrays.asList(toArray(new CreateNoVariable[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/instanceaccess/impl/CreateNoVariableSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.instanceaccess.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.body.ACT_SMTSet;
import io.ciera.tool.sql.ooaofooa.body.impl.ACT_SMTSetImpl;
import io.ciera.tool.sql.ooaofooa.instanceaccess.CreateNoVariable;
import io.ciera.tool.sql.ooaofooa.instanceaccess.CreateNoVariableSet;
import io.ciera.tool.sql.ooaofooa.subsystem.ModelClassSet;
import io.ciera.tool.sql.ooaofooa.subsystem.impl.ModelClassSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class CreateNoVariableSetImpl extends InstanceSet<CreateNoVariableSet,CreateNoVariable> implements CreateNoVariableSet {

    public CreateNoVariableSetImpl() {
    }

    public CreateNoVariableSetImpl(Comparator<? super CreateNoVariable> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setObj_ID( UniqueId ref_Obj_ID ) throws XtumlException {
        for ( CreateNoVariable createnovariable : this ) createnovariable.setObj_ID( ref_Obj_ID );
    }
    @Override
    public void setStatement_ID( UniqueId ref_Statement_ID ) throws XtumlException {
        for ( CreateNoVariable createnovariable : this ) createnovariable.setStatement_ID( ref_Statement_ID );
    }
    @Override
    public void setModelClassKeyLettersColumn( int m_modelClassKeyLettersColumn ) throws XtumlException {
        for ( CreateNoVariable createnovariable : this ) createnovariable.setModelClassKeyLettersColumn( m_modelClassKeyLettersColumn );
    }
    @Override
    public void setModelClassKeyLettersLineNumber( int m_modelClassKeyLettersLineNumber ) throws XtumlException {
        for ( CreateNoVariable createnovariable : this ) createnovariable.setModelClassKeyLettersLineNumber( m_modelClassKeyLettersLineNumber );
    }


    // selections
    @Override
    public ACT_SMTSet R603_is_a_ACT_SMT() throws XtumlException {
        ACT_SMTSet act_smtset = new ACT_SMTSetImpl();
        for ( CreateNoVariable createnovariable : this ) act_smtset.add( createnovariable.R603_is_a_ACT_SMT() );
        return act_smtset;
    }
    @Override
    public ModelClassSet R672_instance_of_ModelClass() throws XtumlException {
        ModelClassSet modelclassset = new ModelClassSetImpl();
        for ( CreateNoVariable createnovariable : this ) modelclassset.add( createnovariable.R672_instance_of_ModelClass() );
        return modelclassset;
    }


    @Override
    public CreateNoVariable nullElement() {
        return CreateNoVariableImpl.EMPTY_CREATENOVARIABLE;
    }

    @Override
    public CreateNoVariableSet emptySet() {
      return new CreateNoVariableSetImpl();
    }

    @Override
    public CreateNoVariableSet emptySet(Comparator<? super CreateNoVariable> comp) {
      return new CreateNoVariableSetImpl(comp);
    }

    @Override
    public CreateNoVariableSet value() {
        return this;
    }

    @Override
    public List<CreateNoVariable> elements() {
        return Arrays.asList(toArray(new CreateNoVariable[0]));
    }

}
